#
# spec file for package k8tz
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           k8tz
Version:        0.17.1
Release:        1.1
Summary:        CLI tool to inject timezones into Kubernetes Pods and CronJobs
License:        Apache-2.0
URL:            https://github.com/k8tz/k8tz
Source:         k8tz-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.18

%description
k8tz is a kubernetes admission controller and a CLI tool to inject timezones
into Pods and CronJobs.

Containers do not inherit timezones from host machines and have only accessed
to the clock from the kernel. The default timezone for most images is UTC, yet
it is not guaranteed and may be different from container to container. With
k8tz it is easy to standardize selected timezone across pods and namespaces
automatically with minimal effort.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/k8tz/k8tz/pkg/version.GitCommit=v=%{version} \
   -X github.com/k8tz/k8tz/pkg/version.AppVersion=%{version} \
   -X github.com/k8tz/k8tz/pkg/version.VersionSuffix= \
   -X github.com/k8tz/k8tz/pkg/version.ImageRepository=quay.io/k8tz/k8tz" \
   -o bin/k8tz

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{name}

%changelog
* Fri Oct 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.17.1:
  * build: release v0.17.1
  * fix(helm): don't render secret permissions when cert-manager is
    not used
  * build(helm): release helm chart 0.17.0
  * build(goreleaser): fix recent deprecation notices and
    validation warnings
* Sat Sep 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.17.0:
  * build: release v0.17.0
  * build: bump tzdata version to 2024b
  * build(helm): release helm chart 0.16.2
* Thu Jun 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.16.2:
  * build: release v0.16.2
  * fix: revert volume name back to "k8tz" after it changed by
    mistake to initContainer name
  * build(helm): release helm chart 0.16.1
* Sat Jun  1 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.16.1:
  * build: release v0.16.1
  * build(deps): bump golang.org/x/net from 0.17.0 to 0.23.0
  * docs: remove trailing space in values.yaml
  * docs: fix table format in charts readme
  * Remove duplicate resources entries in values.yaml; Document new
    initContainerResources param in helm chart's readme
  * Patch the init container with compute resources
  * build(deps): bump google.golang.org/protobuf from 1.28.1 to
    1.33.0
  * build(helm): release helm chart 0.16.0
  * docs: fix typo in changelog
* Thu Apr 18 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- do not strip aka remove -s -w ldflags
* Thu Feb  8 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.16.0:
  * build: release v0.16.0
  * build: bump tzdata version to 2024a
  * feat: add verbose flag to bootstrap initContainer
  * build(helm): release helm chart 0.15.0
* Sun Jan  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.15.0:
  * build: release v0.15.0
  * build: bump tzdata version to 2023d
  * build(helm): release helm chart 0.14.1
* Sun Jan  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.14.1:
  * build: release v0.14.1
  * refactor(helm): allow using helm built-in namespace
  * chore(helm): Add possibility to set topologySpreadConstraints
    to k8tz controller
  * build(deps): bump golang.org/x/net from 0.7.0 to 0.17.0
  * test: add testcase covering custom initContainerName
  * chore: Upgrade to go 1.21
  * build(helm): release helm chart 0.14.0
  * fix(test): add default container name
  * feat(helm): support overriding injected initContainer name
  * feat: support overriding injected initContainer name
* Fri Oct 13 2023 Johannes Kastl <kastl@b1-systems.de>
- new package k8tz: CLI tool to inject timezones into Kubernetes
  Pods and CronJobs
